==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/da.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lagerplads er ikke tilgængeligt",
    "Storage invalid" : "Lagerplads er ugyldig",
    "Unknown error" : "Ukendt fejl",
    "Unable to set upload directory." : "Ude af stand til at vælge upload mappe.",
    "Invalid Token" : "Ugyldig Token ",
    "No file was uploaded. Unknown error" : "Ingen fil blev uploadet. Ukendt fejl.",
    "There is no error, the file uploaded with success" : "Der skete ingen fejl, filen blev succesfuldt uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The uploaded file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Failed to write to disk" : "Fejl ved skrivning til disk.",
    "Not enough storage available" : "Der er ikke nok plads til rådlighed",
    "The target folder has been moved or deleted." : "Mappen er blevet slettet eller fjernet.",
    "Upload failed. Could not find uploaded file" : "Upload fejlede. Kunne ikke finde den uploadede fil.",
    "Upload failed. Could not get file info." : "Upload fejlede. Kunne ikke hente filinformation.",
    "Invalid directory." : "Ugyldig mappe.",
    "Files" : "Filer",
    "All files" : "Alle filer",
    "Home" : "Hjemme",
    "Close" : "Luk",
    "Favorites" : "Foretrukne",
    "Upload cancelled." : "Upload afbrudt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
    "Total file size {size1} exceeds upload limit {size2}" : "Den totale filstørrelse {size1} er større end uploadgrænsen {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
    "Error uploading file \"{fileName}\": {message}" : "Fejl under upload af filen \"{fileName}\": {message}",
    "Could not get result from server." : "Kunne ikke hente resultat fra server.",
    "Uploading..." : "Uploader...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fil upload kører. Hvis du forlader siden nu, vil uploadet blive annuleret.",
    "Actions" : "Handlinger",
    "Download" : "Download",
    "Rename" : "Omdøb",
    "Delete" : "Slet",
    "Disconnect storage" : "Frakobl lager",
    "Unshare" : "Ophæv deling",
    "Details" : "Detaljer",
    "Select" : "Vælg",
    "Pending" : "Afventer",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
    "{newName} already exists" : "{newName} eksistere allerede",
    "Error deleting file \"{fileName}\"." : "Fejl under sletning af filen \"{fileName}\"",
    "No entries in this folder match '{filter}'" : "Der er ingen poster i denne mappe, der matcher '{filter}'",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opbevaringspladsen tilhørende {owner} er fyldt op - filer kan ikke længere opdateres eller synkroniseres!",
    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opbevaringspladsen tilhørende {owner} er næsten fyldt op ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Din opbevaringsplads er næsten fyldt op ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["match '{filter}'","match '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gjort til foretrukken",
    "Favorite" : "Foretrukken",
    "Local link" : "Lokalt link",
    "Folder" : "Mappe",
    "New folder" : "Ny Mappe",
    "{newname} already exists" : "{newname} eksistere allerede",
    "Upload" : "Upload",
    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapper er blevet <strong>oprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begræns noter om oprettelse og ændringer af dine <strong>favorit filer</strong> <em>(Kun streaming)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe er blevet <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe er blevet <strong>gendannet</strong>",
    "You created %1$s" : "Du oprettede %1$s ",
    "%2$s created %1$s" : "%2$s oprettede %1$s",
    "%1$s was created in a public folder" : "%1$s blev oprettet i en offentlig mappe",
    "You changed %1$s" : "Du ændrede %1$s",
    "%2$s changed %1$s" : "%2$s ændrede %1$s",
    "You deleted %1$s" : "Du slettede %1$s",
    "%2$s deleted %1$s" : "%2$s slettede %1$s",
    "You restored %1$s" : "Du gendannede %1$s",
    "%2$s restored %1$s" : "%2$s gendannede %1$s",
    "Changed by %2$s" : "Ændret af %2$s",
    "Deleted by %2$s" : "Slettet af %2$s",
    "Restored by %2$s" : "Gendannet af %2$s",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Maksimal upload-størrelse",
    "max. possible: " : "max. mulige: ",
    "Save" : "Gem",
    "Missing permissions to edit from here." : "Rettighed mangler til at redigere på dette sted",
    "Settings" : "Indstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "No files in here" : "Her er ingen filer",
    "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Upload too large" : "Upload er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
    "No favorites" : "Ingen foretrukne",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekst file.txt"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/da.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagerplads er ikke tilgængelig lige nu",
    "Storage invalid" : "Lagerplads er ugyldig",
    "Unknown error" : "Ukendt fejl",
    "All files" : "Alle filer",
    "Saved" : "Gemt",
    "There was an error saving" : "Der opstod en fejl under gemning",
    "File could not be found" : "Fil kunne ikke findes",
    "Home" : "Hjemme",
    "Close" : "Luk",
    "Favorites" : "Foretrukne",
    "Could not create folder \"{dir}\"" : "Kunne ikke oprette mappen \"{dir}\"",
    "Upload cancelled." : "Upload afbrudt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
    "Target folder \"{dir}\" does not exist any more" : "Mål mappen \"{dir}\" findes ikke mere",
    "Not enough free space" : "Ikke nok ledig plads",
    "Uploading..." : "Uploader...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fil upload kører. Hvis du forlader siden nu, vil uploadet blive annuleret.",
    "Actions" : "Handlinger",
    "Download" : "Download",
    "Rename" : "Omdøb",
    "Delete" : "Slet",
    "Disconnect storage" : "Frakobl lager",
    "Unshare" : "Ophæv deling",
    "Could not load info for file \"{file}\"" : "Kunne ikke indlæse info for filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Vælg",
    "Pending" : "Afventer",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "Invalid path" : "Ugyldig sti",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
    "{newName} already exists" : "{newName} eksistere allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunne ikke omdøbe \"{fileName}\", det eksisterer ikke længere",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" bruges allerede i mappen \"{dir}\". Vælg et andet navn.",
    "Could not rename \"{fileName}\"" : "Kunne ikke omdøbe \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunne ikke oprette filen \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunne ikke oprette filen \"{file}\", fordi den allerede findes",
    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke oprette mappen \"{dir}\", fordi den allerede findes",
    "Error deleting file \"{fileName}\"." : "Fejl under sletning af filen \"{fileName}\"",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["herunder %n skjult","herunder %n skjulte"],
    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opbevaringspladsen tilhørende {owner} er fyldt op - filer kan ikke længere opdateres eller synkroniseres!",
    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opbevaringspladsen tilhørende {owner} er næsten fyldt op ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Din opbevaringsplads er næsten fyldt op ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["match '{filter}'","match '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gjort til foretrukken",
    "Favorite" : "Foretrukken",
    "Folder" : "Mappe",
    "New folder" : "Ny Mappe",
    "{newname} already exists" : "{newname} eksistere allerede",
    "Upload" : "Upload",
    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapper er blevet <strong>oprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begræns noter om oprettelse og ændringer af dine <strong>favorit filer</strong> <em>(Kun streaming)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe er blevet <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe er blevet <strong>gendannet</strong>",
    "You created %1$s" : "Du oprettede %1$s ",
    "%2$s created %1$s" : "%2$s oprettede %1$s",
    "%1$s was created in a public folder" : "%1$s blev oprettet i en offentlig mappe",
    "You changed %1$s" : "Du ændrede %1$s",
    "%2$s changed %1$s" : "%2$s ændrede %1$s",
    "You deleted %1$s" : "Du slettede %1$s",
    "%2$s deleted %1$s" : "%2$s slettede %1$s",
    "You restored %1$s" : "Du gendannede %1$s",
    "%2$s restored %1$s" : "%2$s gendannede %1$s",
    "Changed by %2$s" : "Ændret af %2$s",
    "Deleted by %2$s" : "Slettet af %2$s",
    "Restored by %2$s" : "Gendannet af %2$s",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Maksimal upload-størrelse",
    "max. possible: " : "max. mulige: ",
    "Save" : "Gem",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det tage 5 minutter før ændringer bliver aktive.",
    "Missing permissions to edit from here." : "Rettighed mangler til at redigere på dette sted",
    "Settings" : "Indstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Brug denne adresse til at få <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> adgang til dine filer via WebDAV </a>",
    "No files in here" : "Her er ingen filer",
    "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Upload too large" : "Upload er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
    "No favorites" : "Ingen foretrukne",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekst file.txt"
},
"nplurals=2; plural=(n != 1);");
